@@ -16,7 +16,7 @@ function dynare(fname, varargin)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2021 Dynare Team
+% Copyright © 2001-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -90,9 +90,6 @@ else
     end
 end
 
-% disable output paging (it is on by default on Octave)
-more off
-
 % sets default format for save() command
 if isoctave
     save_default_options('-mat')
