@@ -16,7 +16,7 @@ function dynareroot = dynare_config(path_to_dynare)
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2020 Dynare Team
+% Copyright (C) 2001-2021 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,7 +31,7 @@ function dynareroot = dynare_config(path_to_dynare)
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 if nargin && ~isempty(path_to_dynare)
     addpath(path_to_dynare);
@@ -61,6 +61,8 @@ p = {'/distributions/' ; ...
      '/cli/' ; ...
      '/lmmcp/' ; ...
      '/optimization/' ; ...
+     '/ols/' ; ...
+     '/pac-tools/' ; ...
      '/discretionary_policy/' ; ...
      '/accessors/' ; ...
      '/modules/dseries/src/' ; ...
@@ -69,6 +71,7 @@ p = {'/distributions/' ; ...
      '/utilities/dataset/' ; ...
      '/utilities/general/' ; ...
      '/utilities/graphics/' ; ...
+     '/utilities/version/' ; ...
      '/modules/reporting/src/' ; ...
      '/modules/reporting/macros/'};
 
@@ -82,28 +85,19 @@ if ~isoctave
     p{end+1} = '/missing/vec';
 end
 
-% ordeig() doesn't exist in Octave < 5
-if isoctave && octave_ver_less_than('5')
-    p{end+1} = '/missing/ordeig';
-end
-
-% corrcoef with two outputs is missing in Octave < 4.4 (ticket #796)
-if isoctave && octave_ver_less_than('4.4') && ~user_has_octave_forge_package('nan')
-    p{end+1} = '/missing/corrcoef';
-end
-
-%% intersect(…, 'stable') doesn't exist in Octave and in MATLAB < R2013a
-if isoctave || matlab_ver_less_than('8.1')
+%% intersect(…, 'stable') and unique(…, 'stable') doen't exist in Octave < 6
+if isoctave && octave_ver_less_than('6')
     p{end+1} = '/missing/intersect_stable';
+    p{end+1} = '/missing/unique_stable';
 end
 
 % Replacements for functions of the MATLAB statistics toolbox
 if isoctave
-    % These functions were part of Octave < 4.4, they are now in the statistics Forge package
-    if ~octave_ver_less_than('4.4') && ~user_has_octave_forge_package('statistics')
-        % Our replacement functions don't work under Octave (because of gamrnd, see
-        % #1638), hence the statistics toolbox is now a hard requirement
-        error('You must install the "statistics" package from Octave Forge, either with your distribution package manager or with "pkg install -forge statistics"')
+    % Under Octave, these functions are in the statistics Forge package.
+    % Our replacement functions don't work under Octave (because of gamrnd, see
+    % #1638), hence the statistics toolbox is now a hard requirement
+    if ~user_has_octave_forge_package('statistics')
+        error('You must install the "statistics" package from Octave Forge, either with your distribution package manager or with "pkg install -forge io statistics"')
     end
 else
     if ~user_has_matlab_license('statistics_toolbox')
@@ -116,36 +110,20 @@ if ~exist('struct2array')
     p{end+1} = '/missing/struct2array';
 end
 
-% isfile is missing in Octave < 5 and Matlab < R2017b
-if (isoctave && octave_ver_less_than('5')) || (~isoctave && matlab_ver_less_than('9.3'))
+% isfile is missing in MATLAB < R2017b
+if ~isoctave && matlab_ver_less_than('9.3')
     p{end+1} = '/missing/isfile';
 end
 
-% strsplit and strjoin are missing in MATLAB < R2013a
-if ~isoctave && matlab_ver_less_than('8.1')
-    p{end+1} = '/missing/strsplit';
-    p{end+1} = '/missing/strjoin';
-end
-
 % contains and splitlines don't exist in Octave and in MATLAB < R2016b
 if isoctave || matlab_ver_less_than('9.1')
     p{end+1} = '/missing/contains';
     p{end+1} = '/missing/splitlines';
 end
 
-% isrow, iscolumn and ismatrix are missing in Matlab<R2010b
-if ~isoctave && matlab_ver_less_than('7.11')
-    p{end+1} = '/missing/is-row-column-matrix';
-end
-
-%% isdiag is missing in MATLAB < R2014a
-if ~isoctave && matlab_ver_less_than('8.3')
-    p{end+1} = '/missing/isdiag';
-end
-
-%% narginchk is missing in MATLAB < R2011b
-if ~isoctave && matlab_ver_less_than('7.13')
-    p{end+1} = '/missing/narginchk';
+% datetime doesn't exist in Octave and in MATLAB < R2014b
+if isoctave || matlab_ver_less_than('8.4')
+    p{end+1} = '/missing/datetime';
 end
 
 P = cellfun(@(c)[dynareroot(1:end-1) c], p, 'uni',false);
