@@ -29,7 +29,7 @@ else
         nvariables = vobs(o);
         nobservations = nobs(o);
         if nargin>2 && any(cellfun(@isdseries,varargin(2:end)))
-            error('dseries::plot: You cannot pass more two dseries objects!')
+            error('dseries::plot: You cannot pass more than two dseries objects!')
         end
         if ~isequal(nvariables, vobs(varargin{1}))
             error('dseries::plot: The two dseries objects must have the same number of variables!')
