@@ -15,7 +15,7 @@ function from(varargin)   % --*-- Unitary tests --*--
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 lvarargin = lower(varargin);
 
@@ -423,72 +423,88 @@ if ~isempty(idv)
 end
 i = 0;
 
+return
+
 %@test:1
-%$ try
-%$     y = dseries(zeros(400,1),dates('1950Q1')) ;
-%$     v = dseries(randn(400,1),dates('1950Q1')) ;
-%$     u = dseries(randn(400,1),dates('1950Q1')) ;
-%$     from 1950Q2 to 2049Q4 do y(t) = (1+.01*u(t))*y(t-1) + v(t)
-%$     t(1) = 1;
-%$ catch
-%$     t(1) = 0;
-%$ end
-%$
-%$ T = all(t);
+try
+    y = dseries(zeros(400,1),dates('1950Q1')) ;
+    v = dseries(randn(400,1),dates('1950Q1')) ;
+    u = dseries(randn(400,1),dates('1950Q1')) ;
+    from 1950Q2 to 2049Q4 do y(t) = (1+.01*u(t))*y(t-1) + v(t)
+    t(1) = 1;
+catch
+    t(1) = 0;
+end
+
+T = all(t);
 %@eof:1
 
 %@test:2
-%$ try
-%$     y = dseries(zeros(400,1),dates('1950Q1')) ;
-%$     v = dseries(randn(400,1),dates('1950Q1')) ;
-%$     u = dseries(randn(400,1),dates('1950Q1')) ;
-%$     from 1950Q2 to 2049Q3 do y(t) = (1+.01*u(t))*y(t+1) + v(t)
-%$     t(1) = 0;
-%$ catch
-%$     t(1) = 1;
-%$ end
-%$
-%$ T = all(t);
+try
+    y = dseries(zeros(400,1),dates('1950Q1')) ;
+    v = dseries(randn(400,1),dates('1950Q1')) ;
+    u = dseries(randn(400,1),dates('1950Q1')) ;
+    from 1950Q2 to 2049Q3 do y(t) = (1+.01*u(t))*y(t+1) + v(t)
+    t(1) = 0;
+catch
+    t(1) = 1;
+end
+
+T = all(t);
 %@eof:2
 
 %@test:3
-%$ try
-%$     y = dseries(zeros(400,1),dates('1950Q1')) ;
-%$     v = dseries(randn(400,1),dates('1950Q1')) ;
-%$     u = dseries(randn(400,1),dates('1950Q1')) ;
-%$     from 1950Q2 to 2049Q4 do y(t) = v(t) -.5*v(t-1);
-%$     t(1) = 1;
-%$ catch
-%$     t(1) = 0;
-%$ end
-%$
-%$ T = all(t);
+try
+    y = dseries(zeros(400,1),dates('1950Q1')) ;
+    v = dseries(randn(400,1),dates('1950Q1')) ;
+    u = dseries(randn(400,1),dates('1950Q1')) ;
+    from 1950Q2 to 2049Q4 do y(t) = v(t) -.5*v(t-1);
+    t(1) = 1;
+catch
+    t(1) = 0;
+end
+
+T = all(t);
 %@eof:3
 
 %@test:4
-%$ try
-%$     y = dseries(zeros(400,1),dates('1950Q1')) ;
-%$     v = dseries(randn(400,1),dates('1950Q1')) ;
-%$     u = dseries(randn(400,1),dates('1950Q1')) ;
-%$     from 1950Q2 to 2049Q4 do y(t) = 2*((v(t) -.5*v(t-1))>0)-1;
-%$     t(1) = 1;
-%$ catch
-%$     t(1) = 0;
-%$ end
-%$
-%$ T = all(t);
+try
+    y = dseries(zeros(400,1),dates('1950Q1')) ;
+    v = dseries(randn(400,1),dates('1950Q1')) ;
+    u = dseries(randn(400,1),dates('1950Q1')) ;
+    from 1950Q2 to 2049Q4 do y(t) = 2*((v(t) -.5*v(t-1))>0)-1;
+    t(1) = 1;
+catch
+    t(1) = 0;
+end
+
+T = all(t);
 %@eof:4
 
 %@test:5
-%$ try
-%$     y = dseries(zeros(4000,1),dates('1950Q1')) ;
-%$     v = dseries(randn(4000,1),dates('1950Q1')) ;
-%$     u = dseries(randn(4000,1),dates('1950Q1')) ;
-%$     from 1950Q2 to 2949Q4 do y(t) = y(t-1)*(2*((v(t) -.5*v(t-1))>u(t))-1)+u(t); %plot(y)
-%$     t(1) = 1;
-%$ catch
-%$     t(1) = 0;
-%$ end
-%$
-%$ T = all(t);
+try
+    y = dseries(zeros(4000,1),dates('1950Q1')) ;
+    v = dseries(randn(4000,1),dates('1950Q1')) ;
+    u = dseries(randn(4000,1),dates('1950Q1')) ;
+    from 1950Q2 to 2949Q4 do y(t) = y(t-1)*(2*((v(t) -.5*v(t-1))>u(t))-1)+u(t); %plot(y)
+    t(1) = 1;
+catch
+    t(1) = 0;
+end
+
+T = all(t);
 %@eof:5
+
+%@test:6
+try
+    y = dseries(zeros(2*365+1,1),dates('2000-01-01')) ;
+    v = dseries(randn(2*365+1,1),dates('2000-01-01')) ;
+    u = dseries(randn(2*365+1,1),dates('2000-01-01')) ;
+    from 2000-01-02 to 2001-12-31 do y(t) = (1+.01*u(t))*y(t-1) + v(t)
+    t(1) = true;
+catch
+    t(1) = false;
+end
+
+T = all(t);
+%@eof:6
