@@ -39,7 +39,7 @@ function pm3(n1,n2,ifil,B,tit1,tit2,tit3,tit_tex,names1,names2,name3,DirectoryNa
 % GNU General Public License for more details.
 %
 % You should have received a copy of the GNU General Public License
-% along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
+% along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 global options_ M_ oo_
 
@@ -264,7 +264,7 @@ else
         end
         if filter_step_ahead_indicator
             for K_step = 1:length(options_.filter_step_ahead)
-                name4=['Filtered_Variables_',num2str(K_step),'_step_ahead'];
+                name4=['Filtered_Variables_',num2str(options_.filter_step_ahead(K_step)),'_step_ahead'];
                 oo_.(name4).Mean.(name) = squeeze(Mean_filter_step_ahead(K_step,i,:));
                 oo_.(name4).Median.(name) = squeeze(Median_filter_step_ahead(K_step,i,:));
                 oo_.(name4).Var.(name) = squeeze(Var_filter_step_ahead(K_step,i,:));
@@ -307,6 +307,9 @@ if ~options_.nograph && ~options_.no_graph.posterior
     localVars.n2=n2;
     localVars.Distrib=Distrib;
     localVars.varlist=varlist;
+    if options_.TeX
+        localVars.varlist_TeX=varlist_TeX;
+    end
     localVars.MaxNumberOfPlotsPerFigure=MaxNumberOfPlotsPerFigure;
     localVars.name3=name3;
     localVars.tit3=tit3;
@@ -352,28 +355,14 @@ if ~options_.nograph && ~options_.no_graph.posterior
 
         i=0;
         for j=1:length(nvar0)
-            NAMES = [];
-            TEXNAMES = [];
             nvar=nvar0(j);
             while i<nvar
                 i=i+1;
                 if max(abs(Mean(:,i))) > 10^(-6)
                     subplotnum = subplotnum+1;
-                    name = varlist{i};
-                    texname = varlist_TeX{i};
-                    if subplotnum==1
-                        NAMES = name;
-                        TEXNAMES = ['$' texname '$'];
-                    else
-                        NAMES = char(NAMES,name);
-                        TEXNAMES = char(TEXNAMES,['$' texname '$']);
-                    end
                 end
                 if subplotnum == MaxNumberOfPlotsPerFigure || i == nvar
                     fprintf(fidTeX,'\\begin{figure}[H]\n');
-                    for jj = 1:size(TEXNAMES,1)
-                        fprintf(fidTeX,['\\psfrag{%s}[1][][0.5][0]{%s}\n'],deblank(NAMES(jj,:)),deblank(TEXNAMES(jj,:)));
-                    end
                     fprintf(fidTeX,'\\centering \n');
                     fprintf(fidTeX,['\\includegraphics[width=%2.2f\\textwidth]{%s/Output/%s_' name3 '_%s}\n'],options_.figures.textwidth*min(subplotnum/nn,1),M_.dname,M_.fname, tit3{i});
                     fprintf(fidTeX,'\\label{Fig:%s:%s}\n',name3,tit3{i});
@@ -381,8 +370,6 @@ if ~options_.nograph && ~options_.no_graph.posterior
                     fprintf(fidTeX,'\\end{figure}\n');
                     fprintf(fidTeX,' \n');
                     subplotnum = 0;
-                    NAMES = [];
-                    TEXNAMES = [];
                 end
             end
         end
