@@ -139,7 +139,7 @@ irun = ones(n_variables_to_fill,1);
 ifil = zeros(n_variables_to_fill,1);
 
 run_smoother = 0;
-if options_.smoother || options_.forecast || options_.filter_step_ahead || options_.smoothed_state_uncertainty
+if options_.smoother || options_.forecast || ~isempty(options_.filter_step_ahead) || options_.smoothed_state_uncertainty
     run_smoother = 1;
     if options_.loglinear
         oo_.Smoother.loglinear = true;
